import time

from sharetop.core.oil.oil_detail import get_oil_reserves, get_oil_products, get_oil_consumption,\
    get_oil_refinerythroughput, get_oil_refinerycapacity, get_oil_crudeoilpricehistory

token = "f109298d079b5f60"

# d2 = get_oil_reserves(token, "1")
# print(d1)
#
# d2 = get_oil_products(token, "1")
# print(d2)

# d2 = get_oil_consumption(token, "1")
# d2 = get_oil_refinerythroughput(token, "1", is_explain=False)
d2 = get_oil_crudeoilpricehistory(token)

# d2 = get_oil_refinerycapacity(token, "1", is_explain=False)
print(d2.to_dict("records"))

# for i in range(10):
#     # time.sleep(3)
#     d1 = get_oil_consumption(token, "1")
#     print(d1)




from sharetop.core.prepare import BasicTop


if __name__ == '__main__':
    token = "9ada862fa17ce574"
    sharetop_obj = BasicTop(token)
    # print(sharetop_obj)
    d = sharetop_obj.common_exec_func("bond_yield_to_real_time", {"bond_name": "gcny10"})
    # d = sharetop_obj
    print(d)


from sharetop.core.futures.get_futures_info import get_futures_base_info, get_future_history_data, get_future_deal_detail, get_future_all_realtime_quotes


token = "f109298d079b5f60"


# d = get_futures_base_info(token)

d = get_future_history_data(token, "114.pg2312", is_explain=True)

# d = get_future_deal_detail("114.pg2312")

# d = get_future_all_realtime_quotes(token)

print(d.to_dict("records"))


from sharetop.core.stock.stock_base_info import get_stock_base_info
import requests
import datetime
import re
import pandas as pd


def fund_hk_rank_em() -> pd.DataFrame:
    """
    东方财富网-数据中心-香港基金排行
    https://overseas.1234567.com.cn/FundList
    :return: 香港基金排行
    :rtype: pandas.DataFrame
    """
    format_date = datetime.datetime.now().date().isoformat()
    url = "https://overseas.1234567.com.cn/overseasapi/OpenApiHander.ashx"
    params = {
        'api': 'HKFDApi',
        'm': 'MethodFundList',
        'action': '1',
        'pageindex': '0',
        'pagesize': '5000',
        'dy': '1',
        'date1': format_date,
        'date2': format_date,
        'sortfield': 'Y',
        'sorttype': '-1',
        'isbuy': '0',
        '_': '1610790553848',
    }
    headers = {
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/81.0.4044.138 Safari/537.36",
        "Referer": "http://fund.eastmoney.com/fundguzhi.html",
    }
    r = requests.get(url, params=params, headers=headers)
    data_json = r.json()
    temp_df = pd.DataFrame(data_json["Data"])
    temp_df.reset_index(inplace=True)
    temp_df["index"] = list(range(1, len(temp_df) + 1))
    temp_df.columns = [
        "序号",
        "_",
        "香港基金代码",
        "基金代码",
        "_",
        "基金简称",
        "可购买",
        "日期",
        "单位净值",
        "日增长率",
        "_",
        "近1周",
        "近1月",
        "近3月",
        "近6月",
        "近1年",
        "近2年",
        "近3年",
        "今年来",
        "成立来",
        "币种",
    ]
    temp_df = temp_df[
        [
            "序号",
            "基金代码",
            "基金简称",
            "币种",
            "日期",
            "单位净值",
            "日增长率",
            "近1周",
            "近1月",
            "近3月",
            "近6月",
            "近1年",
            "近2年",
            "近3年",
            "今年来",
            "成立来",
            "可购买",
            "香港基金代码",
        ]
    ]
    temp_df['日期'] = pd.to_datetime(temp_df['日期']).dt.date
    temp_df['单位净值'] = pd.to_numeric(temp_df['单位净值'], errors="coerce")
    temp_df['日增长率'] = pd.to_numeric(temp_df['日增长率'], errors="coerce")
    temp_df['近1周'] = pd.to_numeric(temp_df['近1周'], errors="coerce")
    temp_df['近1月'] = pd.to_numeric(temp_df['近1月'], errors="coerce")
    temp_df['近3月'] = pd.to_numeric(temp_df['近3月'], errors="coerce")
    temp_df['近6月'] = pd.to_numeric(temp_df['近6月'], errors="coerce")
    temp_df['近1年'] = pd.to_numeric(temp_df['近1年'], errors="coerce")
    temp_df['近2年'] = pd.to_numeric(temp_df['近2年'], errors="coerce")
    temp_df['近3年'] = pd.to_numeric(temp_df['近3年'], errors="coerce")
    temp_df['今年来'] = pd.to_numeric(temp_df['今年来'], errors="coerce")
    temp_df['成立来'] = pd.to_numeric(temp_df['成立来'], errors="coerce")
    temp_df['成立来'] = pd.to_numeric(temp_df['成立来'], errors="coerce")
    temp_df['可购买'] = temp_df['可购买'].map(lambda x: "可购买" if x == "1" else "不可购买")
    return temp_df


if __name__ == '__main__':
    # t1 = '012768,华夏中证动漫游戏ETF联接A,HXZZDMYXETFLJA,2023-04-28,1.6020,1.6020,9.40,12.10,32.20,78.38,121.61,108.51,,,94.82,60.20,2021-08-31,1,96.1793,1.20%,0.12%,1,0.12%,1,'

    r = fund_hk_rank_em()
    print(r)


# from sharetop.core.fund.get_fund_rank import fund_open_fund_rank, fund_exchange_rank, fund_money_rank, fund_hk_rank

import pandas as pd


h = [{"a": 1, "b": 2}, {"a": 3, "b": 5}]

df = pd.DataFrame(h)
print(df)


def validate_request(func):
    def wrapper(*args, **kwargs):
        # 执行校验逻辑，可以是任何你需要的操作
        print("args:", args)
        print("kwargs:", kwargs)
        print("进行请求校验")

        # 执行被装饰的函数
        return func(*args, **kwargs)

    return wrapper


# 示例函数1，需要进行请求校验
@validate_request
def function1(token, b):
    print("执行函数1")


# 示例函数2，也需要进行请求校验
@validate_request
def function2():
    print("执行函数2")


# 调用函数1
function1("qq", 'ggg')

# 调用函数2
function2()



import pkgutil
import importlib
import inspect


def get_classes_and_functions_in_package(package_name):
    items = {}  # 用于存储类和函数的字典

    # 使用 pkgutil.walk_packages 遍历包内的模块
    for loader, module_name, is_pkg in pkgutil.walk_packages(package_name.__path__):
        # 导入模块
        module = importlib.import_module(package_name.__name__ + '.' + module_name)

        # 获取模块内的成员
        for name, obj in inspect.getmembers(module):
            # 检查成员是否是函数或类
            if inspect.isfunction(obj) or inspect.isclass(obj):
                items[name] = obj

    return items


# 获取本项目中的包
import sharetop  # 替换成你的项目中的包名

# 调用函数，传入包的名称（模块）
classes_and_functions_in_package = get_classes_and_functions_in_package(sharetop)

# 打印包内的类和函数
for name, item in classes_and_functions_in_package.items():
    print(f"Name: {name}")
    if inspect.isfunction(item):
        print("Type: Function")
    elif inspect.isclass(item):
        print("Type: Class")
    print()



from sharetop.core.capital_flow.capital_flow_monitor import get_stock_real_time_daily_capital, \
    get_stock_real_time_sum_capital, get_stock_real_time_sector_capital, get_stock_history_capital

stock_code = "002714"
token = "f109298d079b5f60"


# d = get_stock_real_time_daily_capital(stock_code, is_explain=True)

# d = get_stock_history_capital(token, stock_code, is_explain=False)

# d = get_stock_real_time_sum_capital(stock_code, is_explain=True)

d = get_stock_real_time_sector_capital("area", "1", is_explain=True)

print("d====:", d.to_dict("records"))



from sharetop.core.stock.getter import get_stock_kline_data, get_stock_real_time_data, get_stock_market_real_time_data
from sharetop.core.stock.quarterly_report import get_stock_all_report_dates, get_stock_company_report_data, get_stock_all_company_quarterly_report
from sharetop.core.stock.rank_list import get_stock_dragon_tiger_list

from sharetop.core.stock.stock_base_info import get_stock_base_info

token = "9ada862fa17ce574"


# d = get_stock_kline_data(token, "516110", is_explain=False)

# d = get_real_time_bill("002714")

# d = get_history_data(token, "002714", klt=102)

# d = get_real_time_data(["002714", "516110"])

# d = get_stock_market_real_time_data(token, "cn10y", is_explain=False)

# d = get_stock_company_report_data(token, '002714', None, False)

# d = get_stock_all_company_quarterly_report(token, '2013-12-31', is_explain=True)

# d = get_stock_dragon_tiger_list(token, '2023-07-21', '2023-08-03')

# d = get_stock_base_info("002714")
# d = get_stock_base_info(["002714", "600809"], is_explain=True)

# d = get_stock_all_report_dates(token, is_explain=False)

d = get_stock_real_time_data("002714", is_explain=False)

print(d)

# print(type(d.to_dict("records")[0]['free_float_market_cap']))



from sharetop.core.capital_flow.capital_flow_monitor import get_stock_real_time_sum_capital, get_stock_history_capital, get_stock_real_time_daily_capital, get_sector_real_time_capital_flow
from enum import Enum
# d = {"a": 1, "b":2}
# d = get_real_time_capital_flow(["002714", "300033"])
# d = get_real_time_capital_flow(['002714', '300033'])
d = get_sector_real_time_capital_flow('area', '10')

# d = get_real_time_capital_flow("000001")

# print(d)
# print(d.to_dict("records"))
import requests

url = 'http://127.0.0.1:8000/sharetopapi/oil/reserves'
access_token = 'eyJ0eXAiOiJKV1QiLCJhbGciOiJIUzI1NiJ9.eyJzdWIiOiJseHkiLCJleHAiOjE2ODUyNzA0NDd9.lPUylZYeHgrWsLEpvqKTU03nioNEyDFJ-SK3vX9UEhQ'
headers = {
    'Authorization': f'Bearer {access_token}'
}

# response = requests.get(url, headers=headers)
#
# r = response.text
#
# print(r)

# h = "2d029512847cf13c"

# print(len(h))

# from sharetop.core.bond.get_bond_info import get_bond_base_info_list, get_bond_realtime_quotes, get_bond_base_info, get_bond_public
token = "f109298d079b5f60"
# d = get_bond_public(token)
# print("d=============:", d)

# d = get_real_time_capital_flow('002714')
print("d=============:", d.to_dict("records"))



from sharetop.core.pig.pig_detail import get_pig_fcr

token = "f109298d079b5f60"


start_date = '2023-05-01'
end_date = '2023-05-16'

d = get_pig_fcr(token, start_date, end_date, is_explain=True)

print(d.to_dict("records"))


from sharetop.core.fund.fund_list import get_fund_codes
from sharetop.core.fund.get_fund_base_info import get_fund_base_info
from sharetop.core.fund.get_fund_history_data import get_fund_history_price
from sharetop.core.fund.get_fund_industry_info import get_fund_industry_distribution
from sharetop.core.fund.get_fund_invest_info import get_fund_public_dates, get_fund_invest_position
from sharetop.core.fund.get_fund_rank import get_fund_open_rank, get_fund_exchange_rank, get_fund_money_rank, get_fund_hk_rank
from sharetop.core.fund.get_period_change_info import get_fund_period_change
from sharetop.core.fund.get_types_percentage_info import get_fund_types_percentage
from sharetop.core.fund.get_fund_real_time import get_fund_real_time_god
from sharetop.core.prepare import BasicTop


token = "f109298d079b5f60"

# d = get_fund_base_info(token, "001299", is_explain=False)

# d = get_fund_history_price(token, "001299", is_explain=True)

# d = get_public_dates(token, "001299")

# d = get_fund_industry_distribution(token, "161725", "2023-03-31", is_explain=False)

# d = get_fund_invest_position(token, "161725", "2023-03-31")

# d = get_fund_public_dates(token, "161725")

# d = fund_open_fund_rank(token, "债券型")

# d = get_fund_open_rank(token, is_explain=False)

# d = get_fund_exchange_rank(token, is_explain=True)

# d = get_fund_money_rank(token)

# d = get_fund_period_change(token, "161725", is_explain=True)

# d = get_fund_types_percentage(token, "161725")

# d = get_fund_real_time_god("161725", is_explain=True)
# d = fund_money_rank(token)

# d = get_period_change(token, "001299")

# d = get_types_percentage(token, "001299")

# d = get_fund_codes(token, is_explain=True)

# d = get_fund_hk_rank(token, is_explain=False)

# print(d)

if __name__ == '__main__':
    token = "9ada862fa17ce574"
    sharetop_obj = BasicTop(token)
    # print(sharetop_obj.class_map)
    d = sharetop_obj.common_exec_func("fund_to_etf", {"is_explain": False})
    print(d)


import requests
import pandas as pd

def index_value_name_funddb() -> pd.DataFrame:
    """
    funddb-指数估值-指数代码
    https://funddb.cn/site/index
    :return: pandas.DataFrame
    :rtype: 指数代码
    """
    url = "https://api.jiucaishuo.com/v2/guzhi/showcategory"
    r = requests.get(url)
    data_json = r.json()
    temp_df = pd.DataFrame(data_json["data"]["right_list"])
    temp_df.columns = [
        "指数开始时间",
        "-",
        "指数名称",
        "指数代码",
        "最新PE",
        "最新PB",
        "PE分位",
        "PB分位",
        "股息率",
        "-",
        "-",
        "-",
        "更新时间",
        "股息率分位",
        "-",
        "-",
        "-",
        "-",
        "-",
        "-",
        "-",
        "-",
        "-",
        "-",
        "-",
        "-",
        "-",
        "-",
        "-",
        "-",
    ]
    temp_df = temp_df[
        [
            "指数名称",
            "最新PE",
            "PE分位",
            "最新PB",
            "PB分位",
            "股息率",
            "股息率分位",
            "指数代码",
            "指数开始时间",
            "更新时间",
        ]
    ]
    temp_df["指数开始时间"] = pd.to_datetime(temp_df["指数开始时间"]).dt.date
    temp_df["最新PE"] = pd.to_numeric(temp_df["最新PE"], errors="coerce")
    temp_df["PE分位"] = pd.to_numeric(temp_df["PE分位"], errors="coerce")
    temp_df["最新PB"] = pd.to_numeric(temp_df["最新PB"], errors="coerce")
    temp_df["PB分位"] = pd.to_numeric(temp_df["PB分位"], errors="coerce")
    temp_df["股息率"] = pd.to_numeric(temp_df["股息率"], errors="coerce")
    temp_df["股息率分位"] = pd.to_numeric(temp_df["股息率分位"], errors="coerce")
    return temp_df

if __name__ == '__main__':
    d = index_value_name_funddb()
    print(d.to_dict("records"))




get_stock_market_real_time_data_fields = {
    "股票代码": "stock_code",
    "股票名称": "stock_name",
    "涨跌幅": "percentage_change",
    "最新价": "last_price",
    "最高": "high_price",
    "最低": "low_price",
    "今开": "open_price",
    "涨跌额": "price_change",
    "换手率": "turnover_rate",
    "量比": "volume_ratio",
    "动态市盈率": "price_to_earnings_ratio",
    "成交量": "trading_volume",
    "成交额": "trading_volume",
    "昨日收盘": "previous_close",
    "总市值": "market_cap",
    "流通市值": "free_float_market_cap",
    "行情ID": "item_id",
    "市场类型": "market_type",
    "更新时间": "update_time",
    "最新交易日": "latest_trading_day"
}

h = []

for k, v in get_stock_market_real_time_data_fields.items():
    temp_data = {
        "name": v,
        "data_type": "str",
        "show": "Y",
        "description": k
    }
    h.append(temp_data)
print(h)




from sharetop.core.car.car_detail import get_car_sales


# token = "9ada862fa17ce574"
#
# d = get_car_sales(token, car_type='suv', pub_date='202302', is_explain=True)
#
# print(d)

import requests
import json
from sharetop.core.prepare import BasicTop

# url = "https://fundgz.1234567.com.cn/js/502003.js"
#
# r = requests.get(url)
#
# data = r.text
#
# deal_data = data.replace("jsonpgz(", "").replace(");", "")
#
# data_json = json.loads(deal_data)
#
# print(data_json)

if __name__ == '__main__':
    token = "9ada862fa17ce574"
    sharetop_obj = BasicTop(token)
    # print(sharetop_obj.class_map)
    d = sharetop_obj.common_exec_func("car_to_kline_data", {"car_type": "suv", "limit": 10, "is_explain": True})
    print(d)